<!DOCTYPE TS><TS>
<defaultcodec></defaultcodec>
<context>
    <name></name>
    <message>
        <source>Error in config.py:</source>
        <translation>Feil i config.py:</translation>
    </message>
    <message>
        <source>Error when running plugin:</source>
        <translation>Feil ved kjøring av programtillegg:</translation>
    </message>
    <message>
        <source>Unable to load file.</source>
        <translation>Klarte ikke åpne fil.</translation>
    </message>
    <message>
        <source>Invalid file format.</source>
        <translation>Ugyldig filformat.</translation>
    </message>
    <message>
        <source>Unable to save file.</source>
        <translation>Klarte ikke lagre fil.</translation>
    </message>
    <message>
        <source>Unable to parse XML:</source>
        <translation>Klarte ikke tolke XML:</translation>
    </message>
    <message>
        <source>Unrecognised encoding.</source>
        <translation>Ukjent koding.</translation>
    </message>
    <message>
        <source>Missing answer on line:</source>
        <translation>Manglende svar på linje:</translation>
    </message>
    <message>
        <source>Unable to load database.
Creating tmp file.</source>
        <translation>Klarte ikke laste database.
Oppretter tmp fil.</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>File exists:</source>
        <translation>Filen finnes:</translation>
    </message>
    <message>
        <source>&amp;Overwrite</source>
        <translation>&amp;Overskriv</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>Removed duplicates: </source>
        <translation>Fjernet duplikater:</translation>
    </message>
    <message>
        <source>There are cards with different answers for question:

</source>
        <translation>Det finnes kort med ulike svar på spørsmål:

</translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation>&amp;Slå sammen og rediger</translation>
    </message>
    <message>
        <source>&amp;Don&apos;t merge</source>
        <translation>&amp;Ikke slå sammen</translation>
    </message>
    <message>
        <source>Done!</source>
        <translation>Ferdig!</translation>
    </message>
    <message>
        <source>You don&apos;t remember this card yet.</source>
        <translation type="unfinished">Du har ikke memorisert dette kortet enda.</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but it&apos;s getting more familiar.</source>
        <translation type="unfinished">Som &apos;0&apos;, men det begynner å bli mer kjent.</translation>
    </message>
    <message>
        <source> Show it less often.</source>
        <translation type="unfinished"> Vis det sjeldnere.</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this card now,</source>
        <translation type="unfinished">Du har memorisert dette kortet nå,</translation>
    </message>
    <message>
        <source> and will probably remember it for a few days.</source>
        <translation type="unfinished"> og vil sannsynligvis huske det noen dager.</translation>
    </message>
    <message>
        <source>You have forgotten this card completely.</source>
        <translation type="unfinished">Du har glemt dette kortet fullstendig.</translation>
    </message>
    <message>
        <source>Barely correct answer. The interval was way too long.</source>
        <translation type="unfinished">Såvidt riktig svar. Intervallet var antakeligvis for langt.</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort.</source>
        <translation type="unfinished">Riktig svar, men med store anstrengelser.</translation>
    </message>
    <message>
        <source> The interval was probably too long.</source>
        <translation type="unfinished"> Intervallet var antakeligvis for langt.</translation>
    </message>
    <message>
        <source>Correct answer, with some effort.</source>
        <translation type="unfinished">Riktig svar, med litt vanskeligheter.</translation>
    </message>
    <message>
        <source> The interval was probably just right.</source>
        <translation type="unfinished">Intervallet var nok akkurat passe.</translation>
    </message>
    <message>
        <source>Correct answer, but without any</source>
        <translation type="unfinished">Riktig svar, men uten vanskeligheter.</translation>
    </message>
    <message>
        <source> difficulties. The interval was probably too short.</source>
        <translation type="unfinished"> Intervallet var antakeligvis for kort.</translation>
    </message>
</context>
<context>
    <name>AboutDlg</name>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Main author: Peter Bienstman

</source>
        <translation>Hovedutvikler: Peter Bienstman

</translation>
    </message>
    <message>
        <source>More info: http://mnemosyne-proj.org
</source>
        <translation>Mer info: http://mnemosyne-proj.org
</translation>
    </message>
</context>
<context>
    <name>AboutFrm</name>
    <message>
        <source>About</source>
        <translation>Om</translation>
    </message>
</context>
<context>
    <name>ActivateCategoriesFrm</name>
    <message>
        <source>Activate categories</source>
        <translation>Aktiver kategorier</translation>
    </message>
    <message>
        <source>Select the categories to activate:</source>
        <translation>Velg kategoriene som skal aktiveres:</translation>
    </message>
    <message>
        <source>Activate none</source>
        <translation>Aktiver ingen</translation>
    </message>
    <message>
        <source>Activate all</source>
        <translation>Aktiver alle</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
</context>
<context>
    <name>AddItemsDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;standard&gt;</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Abandon current card?</source>
        <translation>Forkaste dette kortet?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Ja</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nei</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Spørsmål:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Svar:</translation>
    </message>
    <message>
        <source>Written form:</source>
        <translation>Skriftlig form:</translation>
    </message>
    <message>
        <source>Translation:</source>
        <translation>Oversettelse:</translation>
    </message>
    <message>
        <source>Card is already in database.
</source>
        <translation>Korten finnes allerede i databasen.
</translation>
    </message>
    <message>
        <source>Duplicate not added.</source>
        <translation>Ikke lagt til duplikat.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>There are different answers for</source>
        <translation>Det er ulike svar på</translation>
    </message>
    <message>
        <source> this question:

</source>
        <translation> dette spørsmålet:

</translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation>&amp;Slå sammen og rediger</translation>
    </message>
    <message>
        <source>&amp;Add as is</source>
        <translation>&amp;Legg til som det er</translation>
    </message>
    <message>
        <source>&amp;Do not add</source>
        <translation>&amp;Ikke legg til</translation>
    </message>
</context>
<context>
    <name>AddItemsFrm</name>
    <message>
        <source>Add cards</source>
        <translation>Legg til kort</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Kategori:</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Spørsmål:</translation>
    </message>
    <message>
        <source>Pronunciation:</source>
        <translation>Uttale:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Svar:</translation>
    </message>
    <message>
        <source>Add &amp;vice versa too</source>
        <translation>Legg til &amp;vice versa også</translation>
    </message>
    <message>
        <source>Alt+V</source>
        <translation>Alt+V</translation>
    </message>
    <message>
        <source>Select initial grade:</source>
        <translation>Velg utgangsnivå:</translation>
    </message>
    <message>
        <source>&amp;0</source>
        <translation>&amp;0</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>You don&apos;t remember this item yet or forgot it.</source>
        <translation>Du har ikke memorisert dette kortet ennå, eller du har glemt det.</translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation>&amp;1</translation>
    </message>
    <message>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but the item is getting more familiar.</source>
        <translation>Som &apos;0&apos;, men det begynner å bli mer kjent.</translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation>&amp;2</translation>
    </message>
    <message>
        <source>Ctrl+2</source>
        <translation>Ctrl+2</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this item now, and will probably remember it for a few days.</source>
        <translation>Du har memorisert dette kortet nå, og vil sannsynligvis huske det noen dager.</translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation>&amp;3</translation>
    </message>
    <message>
        <source>Ctrl+3</source>
        <translation>Ctrl+3</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort. The interval was probably too long</source>
        <translation>Riktig svar, men med store anstrengelser. Intervallet var antakeligvis for langt.</translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation>&amp;4</translation>
    </message>
    <message>
        <source>Ctrl+4</source>
        <translation>Ctrl+4</translation>
    </message>
    <message>
        <source>Correct answer, with some effort. The interval was probably just right.</source>
        <translation>Riktig svar, med litt anstrengelser. Intervallet var antakeligvis akkurat passe.</translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation>&amp;5</translation>
    </message>
    <message>
        <source>Ctrl+5</source>
        <translation>Ctrl+5</translation>
    </message>
    <message>
        <source>Correct answer, but without any difficulties. The interval was probably too short.</source>
        <translation>Riktig svar, men uten vanskeligheter. Intervallet var antakeligvis for kort.</translation>
    </message>
    <message>
        <source>Type question and answer, then pick initial grade.</source>
        <translation>Skriv inn spørsmål og svar, velg så utgangsinvå.</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Forhåndsvis</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Avslutt</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
</context>
<context>
    <name>ChangeCategoryFrm</name>
    <message>
        <source>Change category</source>
        <translation>Skift kategori</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Kategori:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
<context>
    <name>ConfigurationFrm</name>
    <message>
        <source>Mnemosyne configuration</source>
        <translation>Mnemosyne oppsett</translation>
    </message>
    <message>
        <source>Hover with the mouse over the buttons to get extra information.</source>
        <translation>Hold musepekeren over knappene for å få mer informasjon.</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Utseende</translation>
    </message>
    <message>
        <source>Set Q/A font</source>
        <translation>Angi spørsmål- og svarskrift</translation>
    </message>
    <message>
        <source>Set the font used when showing single questions and answers</source>
        <translation>Angi font som brukes ved visning av enkeltspørsmål og svar</translation>
    </message>
    <message>
        <source>Set list font</source>
        <translation>Angi listeskrift</translation>
    </message>
    <message>
        <source>Set the font used when showing the list of all the cards in the deck</source>
        <translation>Angi font som brukes ved visning av listen med alle kortene i kortstokken</translation>
    </message>
    <message>
        <source>Increase size of non-latin characters by</source>
        <translation>Øk størrelsen på ikke-latinske tegne med</translation>
    </message>
    <message>
        <source>Sometimes complex glyphs are hard to read at the default latin font size</source>
        <translation>Enkelte kompliserte glyffer er vanskelige å lese med standardstørrelsen til latinsk skrift</translation>
    </message>
    <message>
        <source>point(s)</source>
        <translation>punkt(er)</translation>
    </message>
    <message>
        <source>Log uploading</source>
        <translation>Opplasting av logg</translation>
    </message>
    <message>
        <source>Upload anonymous logs</source>
        <translation>Last opp anonym logg</translation>
    </message>
    <message>
        <source>Share anonymous statistics to contribute to memory research</source>
        <translation>Del anonym statistikk for å bidra til minneforskning</translation>
    </message>
    <message>
        <source>Duplicate handling</source>
        <translation>Behandling av duplikater</translation>
    </message>
    <message>
        <source>Check for duplicates when adding new cards</source>
        <translation>Sjekk for duplikater når du legger til nye kort</translation>
    </message>
    <message>
        <source>Allow duplicates in different categories</source>
        <translation>Tillat duplikater i ulike kategorier</translation>
    </message>
    <message>
        <source>Repetition process</source>
        <translation>Repetisjonsprosess</translation>
    </message>
    <message>
        <source>Number of grade 0 cards to hold in your hand:</source>
        <translation>Antall nivå 0-kort å holde i hånden din:</translation>
    </message>
    <message>
        <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
        <translation>Merk: dette er IKKE antall nivå 0-kort du ønsker å memorise *per dag*</translation>
    </message>
    <message>
        <source>Learn new cards in random order</source>
        <translation>Lær nye kort i tilfeldig rekkefølge</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Defaults</source>
        <translation>Standardvalg</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
</context>
<context>
    <name>EditItemFrm</name>
    <message>
        <source>Edit card</source>
        <translation>Rediger kort</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Kategori:</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Spørsmål:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Svar:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Forhåndsvis</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
<context>
    <name>EditItemsDlg</name>
    <message>
        <source>Please wait...</source>
        <translation>Venligst vent...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Rediger</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Forhåndsvis</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Add vice versa</source>
        <translation>Legg til &amp;vice versa</translation>
    </message>
    <message>
        <source>S&amp;tatistics</source>
        <translation>S&amp;tatistikk</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Slett</translation>
    </message>
    <message>
        <source>&amp;Change category</source>
        <translation>Skift &amp;kategori</translation>
    </message>
    <message>
        <source>Add &amp;vice versa</source>
        <translation>Legg til &amp;vice versa</translation>
    </message>
    <message>
        <source>Add vice versa of these cards?</source>
        <translation>Legg til vice versa for disse kortene?</translation>
    </message>
    <message>
        <source>Add vice versa of this card?</source>
        <translation>Legg til vice versa for dette kortet?</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>

This could create duplicates if the vice </source>
        <translation>

Dette kan lage duplikater hvis vice</translation>
    </message>
    <message>
        <source>versas are already present, 
so you might want to run </source>
        <translation>versa allerede finnes,
så du vil kanskje kjøre</translation>
    </message>
    <message>
        <source>clean duplicates&apos; afterwards.</source>
        <translation>fjern duplikater etterpå.</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Ja</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nei</translation>
    </message>
    <message>
        <source>Grade:</source>
        <translation>Nivå:</translation>
    </message>
    <message>
        <source>Easiness:</source>
        <translation>Letthet:</translation>
    </message>
    <message>
        <source>Repetitions:</source>
        <translation>Repetisjoner:</translation>
    </message>
    <message>
        <source>Lapses:</source>
        <translation>Feil svar:</translation>
    </message>
    <message>
        <source>Days since last repetition:</source>
        <translation>Dager siden forrige repetisjon:</translation>
    </message>
    <message>
        <source>Days until next repetition:</source>
        <translation>Dager til neste repetisjon:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Delete these cards?</source>
        <translation>Slett disse kortene?</translation>
    </message>
    <message>
        <source>Delete this card?</source>
        <translation>Slett dette kortet?</translation>
    </message>
    <message>
        <source>The text you entered was not found.</source>
        <translation>Teksten du skrev inn ble ikke funnet.</translation>
    </message>
    <message>
        <source>&amp;Find again</source>
        <translation>&amp;Søk etter neste</translation>
    </message>
    <message>
        <source>F</source>
        <translation>F</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Søk</translation>
    </message>
</context>
<context>
    <name>EditItemsFrm</name>
    <message>
        <source>Question</source>
        <translation>Spørsmål</translation>
    </message>
    <message>
        <source>Answer</source>
        <translation>Svar</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategori</translation>
    </message>
    <message>
        <source>Edit deck</source>
        <translation>Rediger kortstokk</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Søk</translation>
    </message>
    <message>
        <source>Alt+F</source>
        <translation>Alt+F</translation>
    </message>
    <message>
        <source>To edit a card, right-click on it.</source>
        <translation>Vestreklikk på et kort for å redigere det.</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Avslutt</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>All Files (*);;</source>
        <translation>Alle filer (*);;</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Eksport</translation>
    </message>
</context>
<context>
    <name>ExportFrm</name>
    <message>
        <source>Export to file</source>
        <translation>Eksporter til fil</translation>
    </message>
    <message>
        <source>File format:</source>
        <translation>Filformat:</translation>
    </message>
    <message>
        <source>File to export to:</source>
        <translation>Fil som skal eksporteres til:</translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation>&amp;Bla</translation>
    </message>
    <message>
        <source>Categories to export:</source>
        <translation>Kategorier som skal eksporteres:</translation>
    </message>
    <message>
        <source>&amp;Select all</source>
        <translation>&amp;Velg alle</translation>
    </message>
    <message>
        <source>Reset learning data on export</source>
        <translation>Nullstill data ved eksport</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
</context>
<context>
    <name>ImportDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;standard&gt;</translation>
    </message>
    <message>
        <source>All Files (*);;</source>
        <translation>Alle filer (*);;</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Import</translation>
    </message>
</context>
<context>
    <name>ImportFrm</name>
    <message>
        <source>Import from file</source>
        <translation>Import fra fil</translation>
    </message>
    <message>
        <source>File format:</source>
        <translation>Filformat:</translation>
    </message>
    <message>
        <source>File to import from:</source>
        <translation>Fil som skal importeres fra:</translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation>&amp;Bla</translation>
    </message>
    <message>
        <source>Put cards without category into this category:</source>
        <translation>Plasser kort uten kategori i denne kategorien:</translation>
    </message>
    <message>
        <source>Note: all cards will be added to the current database.</source>
        <translation>Merk: alle kort vil bli lagt til den gjeldende databasen.</translation>
    </message>
    <message>
        <source>Reset learning data on import</source>
        <translation>Nullstill data ved eksport</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
</context>
<context>
    <name>MainDlg</name>
    <message>
        <source>Mnemosyne databases (*.mem)</source>
        <translation type="unfinished">Mnemosyne databaser (*.mem)</translation>
    </message>
    <message>
        <source>New</source>
        <translation type="unfinished">Ny</translation>
    </message>
    <message>
        <source>Please wait...</source>
        <translation type="unfinished">Venligst vent...</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation type="unfinished">Mnemosyne</translation>
    </message>
    <message>
        <source>Delete current card?</source>
        <translation type="unfinished">Slett dette kortet?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation type="unfinished">&amp;Ja</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation type="unfinished">&amp;Nei</translation>
    </message>
    <message>
        <source>Returns in </source>
        <translation type="unfinished">Kommer igjen om</translation>
    </message>
    <message>
        <source> day(s).</source>
        <translation type="unfinished"> dag(er).</translation>
    </message>
    <message>
        <source>Next repetition: today.</source>
        <translation type="unfinished">Neste repetisjon: i dag.</translation>
    </message>
    <message>
        <source>Next repetition: tomorrow.</source>
        <translation type="unfinished">Neste repetisjon: i morgen.</translation>
    </message>
    <message>
        <source>Next repetition in </source>
        <translation type="unfinished">Neste repetisjon om</translation>
    </message>
    <message>
        <source> days.</source>
        <translation type="unfinished"> dager.</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation type="unfinished">Spørsmål:</translation>
    </message>
    <message>
        <source>&lt;default&gt;</source>
        <translation type="unfinished">&lt;standard&gt;</translation>
    </message>
    <message>
        <source>Show answer</source>
        <translation type="unfinished">Vis svar</translation>
    </message>
    <message>
        <source>Learn ahead of schedule</source>
        <translation type="unfinished">Lær foran tidsskjema</translation>
    </message>
    <message>
        <source>Pick days until next repetition:</source>
        <translation type="unfinished">Velg antall dager til neste repitisjon:</translation>
    </message>
    <message>
        <source>Grade your answer:</source>
        <translation type="unfinished">Grader ditt svar:</translation>
    </message>
    <message>
        <source>Scheduled: </source>
        <translation type="unfinished">Planlagte repetisjoner:</translation>
    </message>
    <message>
        <source>Not memorised: </source>
        <translation type="unfinished">Ikke memorisert:</translation>
    </message>
    <message>
        <source>All: </source>
        <translation type="unfinished">Alle:</translation>
    </message>
</context>
<context>
    <name>MainFrm</name>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Spørsmål:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Svar:</translation>
    </message>
    <message>
        <source>Show answer</source>
        <translation>Vis svar</translation>
    </message>
    <message>
        <source>Grade your answer:</source>
        <translation>Grader ditt svar:</translation>
    </message>
    <message>
        <source>&amp;0</source>
        <translation>&amp;0</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation>&amp;1</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation>&amp;2</translation>
    </message>
    <message>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation>&amp;3</translation>
    </message>
    <message>
        <source>3</source>
        <translation>3</translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation>&amp;4</translation>
    </message>
    <message>
        <source>4</source>
        <translation>4</translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation>&amp;5</translation>
    </message>
    <message>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Ny</translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>Å&amp;pne...</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>La&amp;gre</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Lagre so&amp;m...</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Avslutt</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Om</translation>
    </message>
    <message>
        <source>Add cards</source>
        <translation>Legg til kort</translation>
    </message>
    <message>
        <source>&amp;Add cards</source>
        <translation>&amp;Legg til kort</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <source>Activate cate&amp;gories</source>
        <translation>Aktiver kate&amp;gorier</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Edit deck</source>
        <translation>Rediger kortstokk</translation>
    </message>
    <message>
        <source>Edit &amp;deck</source>
        <translation>Rediger &amp;kortstokk</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>&amp;Import</source>
        <translation>&amp;Import</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Eksport</translation>
    </message>
    <message>
        <source>Show &amp;toolbar</source>
        <translation>Vis &amp;verktøylinje</translation>
    </message>
    <message>
        <source>Edit current card</source>
        <translation>Rediger dette korter</translation>
    </message>
    <message>
        <source>&amp;Edit current card</source>
        <translation>&amp;Rediger dette kortet</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Delete current card</source>
        <translation>Slett dette kortet</translation>
    </message>
    <message>
        <source>&amp;Delete current card</source>
        <translation>&amp;Slett dette kortet</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <source>&amp;Clean duplicates</source>
        <translation>&amp;Fjern duplikater</translation>
    </message>
    <message>
        <source>&amp;Configure Mnemosyne</source>
        <translation>&amp;Konfigurer Mnemosyne</translation>
    </message>
    <message>
        <source>Getting started</source>
        <translation>Komme igang</translation>
    </message>
    <message>
        <source>&amp;Getting started</source>
        <translation>&amp;Komme igang</translation>
    </message>
    <message>
        <source>Down, Down</source>
        <translation>Ned, Ned</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>Return</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>Mellomrom</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Show statistics</source>
        <translation>Vis statistikk</translation>
    </message>
    <message>
        <source>Show s&amp;tatistics</source>
        <translation>Vis s&amp;tatistikk</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Tip of the day</source>
        <translation>Dagens tips</translation>
    </message>
    <message>
        <source>&amp;Tip of the day</source>
        <translation>&amp;Dagens tips</translation>
    </message>
    <message>
        <source>Main toolbar (Mnemosyne)</source>
        <translation>Hovedverktøylinje (Mnemosyne)</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fil</translation>
    </message>
    <message>
        <source>&amp;Deck</source>
        <translation>&amp;Kortstokk</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Oppsett</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hjelp</translation>
    </message>
</context>
<context>
    <name>PreviewItemDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;standard&gt;</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Spørsmål:</translation>
    </message>
</context>
<context>
    <name>PreviewItemFrm</name>
    <message>
        <source>Preview card</source>
        <translation>Forhåndsvis kort</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Spørsmål:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Svar:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
</context>
<context>
    <name>ProductTourFrm</name>
    <message>
        <source>Getting started</source>
        <translation>Komme igang</translation>
    </message>
    <message>
        <source>Greetings!

I am Mnemosyne, a type of butterfly named after the Greek goddess of Memory. 

I can make it more efficient for you to memorise and remember answers to questions, by helping you focus on the cards you&apos;re most likely to forget and by not wasting your time on things you know well.

For that, I&apos;ll decide when to ask you the questions, and you&apos;ll need to rate how well you remember the answers.

Let&apos;s look at the meaning of these ratings now.</source>
        <translation>Velkommen!

Jeg er Mnemosyne, en slags sommerfugl oppkalt etter den greske gudinnen for hukommelse.

Jeg kan gjøre deg mer effektiv til å memorisere og huske svar på spørsmål ved å hjelpe deg fokusere på de kortene det er mest sannsynlig at du vil glemme, og ikke la deg sløse bort tiden på ting du kan godt.

For å gjøre dette, skal jeg bestemme når spørsmålene skal stilles, og du må angi hvor godt du husker svarene.

La oss nå se på betydningen av nivåene.</translation>
    </message>
    <message>
        <source>Introduction</source>
        <translation>Introduksjon</translation>
    </message>
    <message>
        <source>Grades range from 0 to 5.

Grades 0 and 1 are used if you don&apos;t know the answer yet, or if you have forgotten it. A card with grade 1 is starting to get more familiar than one with grade 0, and will be repeated less often.

I will keep on asking you these questions until you give them a grade 2 or higher (the exact grade doesn&apos;t matter). Grade 2 basically means that you think you&apos;ll be able to remember the card for at least one or two days. It signals the transition between short and long term memory.

I will schedule this card at some future date, when I think you&apos;ll still be able to remember it with some effort, without having forgotten it completely. This is the most efficient for the learning process.</source>
        <translation>Nivåene går fra 0 til 5.

Nivå 0 og 1 brukes hvis du ikke vet svaret enda, eller har glømt det. Et kort med nivå 1 begynner å bli mer kjent enn ett med nivå 0, og vil bli repetert sjeldnere.

Jeg vil fortsette å spørre deg disse spørsmålene til du graderer dem til nivå 2 eller høyere (det eksakte nivået spiller ingen rolle). Nivå 2 betyr at du tror du vil klare å huske kortet for minst en dag eller to. Det signaliserer overgangen mellom kortids- og langtidsminnet.

Jeg vil repetere dette kortet en gang i fremtiden når du fremdeles tror du vil klare å huske det med litt anstrengelser, uten å ha glemt det fullstendig. Dette er mest effektivt for læringsprosessen.</translation>
    </message>
    <message>
        <source>Grades 0-2</source>
        <translation>Nivå 0-2</translation>
    </message>
    <message>
        <source>If in the future I ask you the question too soon, and you&apos;re able to remember it without any effort, you rate the card a 5. I&apos;ll take this into account by waiting a lot longer before asking you this question again.

If I get it just right, so that you remember it, albeit with some effort, you use grade 4.

If on the other hand it takes you significant effort to remember the answer, and you think I&apos;ve waited too long to ask you this question, then rate the card 3.

If you fail to remember it altogether, rate it either 0 or 1, and I&apos;ll keep on asking you this question until you think you&apos;ll be able to remember it again for a few days.</source>
        <translation>Hvis jeg i fremtiden skulle spørre deg for tidlig, og du husker det uten vanskeligheter, graderer du kortet til 5. Jeg vil ta det til etteretning ved å vente lenger før jeg spør deg samme spørsmålet igjen.

Hvis jeg spør akkurat til rett tid slik at du husker det, om enn med litt anstrengelser, så graderer du det til 4.

Hvis det på den andre siden koster deg en betydelig anstrengelse å komme på svaret, og du mener jeg ventet for lenge med å spørre dette spørsmålet, så graderer du kortet til 3.

Hvis du ikke klarer å huske det overhodet, gir du det enten 0 eller 1, så skal jeg fortsette å spørre deg dette spørsmålet til du igjen tror du vil klare å huske det ett par dager.</translation>
    </message>
    <message>
        <source>Grades 3-5</source>
        <translation>Nivå 3-5</translation>
    </message>
    <message>
        <source>If you&apos;re into statistics, I can keep detailed logs of your revisions.

Not only that, but if you want, I can upload transparently a completely anonymous version of these logs to a central site for analysis, so that you can help making me better. In this way, you also contribute to scientific research on long-term memory.

Uncheck the following box if you do not want to do this.</source>
        <translation>Hvis du er interessert i statistikk, så kan jeg føre detaljerte logger over dine revisjoner.

Og ikke bare det, men hvis du vil, så kan jeg også laste opp helt anonyme versjoner av disse loggene til en sentral hjemmeside for analyser, slik at du kan hjelpe meg å bli bedre. På denne måten vil du også bidra til vitenskaptlig forskning på langtidsminne.

Huk av i den følgende avkrysningsboksen hvis du ikke ønsker dette.</translation>
    </message>
    <message>
        <source>Upload anonymous logs</source>
        <translation>Last opp anonyme logger</translation>
    </message>
    <message>
        <source>(You can always change this setting later using the &apos;Configure Mnemosyne&apos; menu option.)</source>
        <translation>(Du kan alltid forandre denne tilpassningen senere, under menyvalget &apos;Konfigurer Mnemosyne&apos;.)</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistikk</translation>
    </message>
    <message>
        <source>Now you&apos;re ready to start!
&lt;p&gt;
Add new cards by clicking on the icon with the &apos;plus&apos; sign in the top left.
&lt;p&gt;
Remember, there is no need to worry about saving your work, I will do so automatically.
&lt;p&gt;
For best results, I suggest you do your revisions every day, although I&apos;ll try to cope as best I can if you postpone your revisions or if you want to learn ahead of time.
&lt;p&gt;
For more documentation, see http://www.mnemosyne-proj.sourceforge.net.
&lt;p&gt;
Happy learning!</source>
        <translation>Nå er du klar til å begynne!
&lt;p&gt;
Legg til nye kort ved å klikke på ikonet med plusstegn øverst til venstre.
&lt;p&gt;
Husk, du trenger ikke bekymre deg for å lagre arbeidet ditt. Det veil jeg gjøre automatisk.
&lt;p&gt;
For best resultat, anbefaler jeg at du repeterer hver dag, selv om jeg skal gjøre som best jeg kan hvis du utsetter repetisjonene dine eller hvis du ønsker å lære forran tidsskjema.
&lt;p&gt;
For mer dokumentasjon, se http://www.mnemosyne-proj.sourceforge.net.
&lt;p&gt;
God læring!</translation>
    </message>
    <message>
        <source>Ready to start</source>
        <translation>Klar til start</translation>
    </message>
</context>
<context>
    <name>QTextEdit2</name>
    <message>
        <source>Insert &amp;image</source>
        <translation>Sett inn &amp;bilde</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Insert &amp;sound</source>
        <translation>Sett inn &amp;lyd</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>&amp;3-sided input</source>
        <translation>&amp;3-sidet kort</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>Bildefiler</translation>
    </message>
    <message>
        <source>Insert image</source>
        <translation>Sett inn bilde</translation>
    </message>
    <message>
        <source>Sound files</source>
        <translation>Lydfiler</translation>
    </message>
    <message>
        <source>Insert sound</source>
        <translation>Sett inn lyd</translation>
    </message>
</context>
<context>
    <name>StatisticsDlg</name>
    <message>
        <source>Scheduled cards for the next days:

</source>
        <translation type="obsolete">Planlagte kort for de neste dagene:

</translation>
    </message>
    <message>
        <source>In</source>
        <translation>Om</translation>
    </message>
    <message>
        <source>day(s) :</source>
        <translation>dag(er):</translation>
    </message>
    <message>
        <source>Number of cards with the following grades:

</source>
        <translation>Antall kort med de ulike nivåene:

</translation>
    </message>
    <message>
        <source>Grade</source>
        <translation>Nivå</translation>
    </message>
    <message>
        <source>No current card.</source>
        <translation>Ingen kort valgt.</translation>
    </message>
    <message>
        <source>Grade:</source>
        <translation>Nivå:</translation>
    </message>
    <message>
        <source>Easiness:</source>
        <translation>Letthet:</translation>
    </message>
    <message>
        <source>Repetitions:</source>
        <translation>Repetisjoner:</translation>
    </message>
    <message>
        <source>Lapses:</source>
        <translation>Feil svar:</translation>
    </message>
    <message>
        <source>Days since last repetition:</source>
        <translation>Dager siden forrige repetisjon:</translation>
    </message>
    <message>
        <source>Days until next repetition:</source>
        <translation>Dager til neste repetisjon:</translation>
    </message>
    <message>
        <source>Scheduled cards for next week:

</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StatisticsFrm</name>
    <message>
        <source>Category</source>
        <translation>Kategori</translation>
    </message>
    <message>
        <source>Cards</source>
        <translation>Kort</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistikk</translation>
    </message>
    <message>
        <source>Schedule</source>
        <translation>Tidsskjema</translation>
    </message>
    <message>
        <source>Grades</source>
        <translation>Nivå</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Kategorier</translation>
    </message>
    <message>
        <source>Current card</source>
        <translation>Gjeldende kort</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
</context>
<context>
    <name>TipDlg</name>
    <message>
        <source>For optimal results, it&apos;s best to do your repetitions every day.</source>
        <translation>For optimale resultater er det best om du repeterer hver dag.</translation>
    </message>
    <message>
        <source>If you&apos;ve been away for a few days, don&apos;t worry about your backlog. Do as many cards as you feel like to catch up, the rest will be automatically rescheduled to the future.</source>
        <translation>Hvis du har vært borte ett par dager, skal du ikke bekymre deg over opparbeidede repetisjoner. Gjør så mange kort du gidder for å hente deg opp igjen. Resten vil automatisk bli skjøvet frem i tid.</translation>
    </message>
    <message>
        <source>The &apos;number of grade 0 cards to learn at once&apos; setting determines how many new cards you are trying to learn at the same time. It does &lt;b&gt;not&lt;/b&gt; tell you how many new cards you need to learn per day. You are the judge of that: you can learn more cards or less cards, depending on how you feel.</source>
        <translation>Antall &apos;nivå 0-kort som skal læres på en gang&apos;-innstillingen bestemmer hvor mange nye kort du prøver å lære på samme tid. Det forteller deg &lt;b&gt;ikke&lt;/b&gt; hvor mange nye kort du trenger å lære per dag. Bare deg selv avgjør det; du kan lære flere eller færre kort, alt etter som du føler for.</translation>
    </message>
    <message>
        <source>In summary, try to do your repetitions every day, but don&apos;t worry too much about getting the &apos;scheduled&apos; counter to zero, and certainly not about getting the &apos;Not memorised&apos; counter to zero.</source>
        <translation>For å oppsummere, prøv å gjøre repetisjonene dine hver dag, men ikke bry deg så mye om å få &apos;Planlagte repetisjoner&apos;-telleren til null, og i hvert fall ikke å få &apos;Ikke memorisert&apos;-telleren til null.</translation>
    </message>
    <message>
        <source>Grade 1 cards are different from grade 0 cards in the sense that they show up less often and are not subject to the &apos;number of grade 0 cards to learn at once&apos; setting.</source>
        <translation>Nivå 1-kort er forskjellige fra nivå 0-kort ved at de dukker opp sjeldnere og ikke er underlagt &apos;antall nivå 0-kort som skal læres på en gang&apos;-instillingen.</translation>
    </message>
    <message>
        <source>You can use keyboard shortcuts to do your repetitions. Enter, Return or Space stand for the default action (&apos;Show answer&apos; or &apos;grade 4&apos;). The number keys can be used for grading.</source>
        <translation>Du kan bruke snarveistastene til å gjøre repetisjonene dine. Enter eller mellomrom står for standardvalget (&apos;Vis svaret&apos; eller &apos;nivå 4). Talltastene kan brukes til gradering.</translation>
    </message>
    <message>
        <source>You can select the categories you wish to study in the &apos;Activate categories&apos; menu option.</source>
        <translation>Du kan velge kategoriene du ønsker å studere i &apos;Aktiver kategorier&apos;-menyvalget.</translation>
    </message>
    <message>
        <source>It is recommended to put all your cards in a single database and use categories to organise them. Using &apos;Activate categories&apos; is much more convenient than have to load and unload several databases.</source>
        <translation>Det anbefales at du plasserer alle kortene dine i én enkelt enkelt database og bruker kategorier for å organisere dem. Bruk av &apos;Aktiver kategoier&apos; er mye mer praktisk enn å måtte laste inn og ut flere databaser.</translation>
    </message>
    <message>
        <source>You can import cards in a wide variety of formats: tab delimited txt files, Supermemo files, ... .</source>
        <translation>Du kan importere kort i ett bred utvalg av formater: tabulatoravgrensede tekstfiler, Supermemo-filer, ... .</translation>
    </message>
    <message>
        <source>If you have cards in Word or Excel, export them to tab delimited txt files with UTF-8 unicode encoding to be able to import them into Mnemosyne.</source>
        <translation>Hvis du har kort i Word eller Excel, eksporter dem til en tabulatoravgrenset tekstfil i UTF-8 unicode-format for å kunne importere dem til Mnemosyne.</translation>
    </message>
    <message>
        <source>If you want to print out your cards, export them to a txt file which you can then print from your favourite Word processor.</source>
        <translation>Hvis du ønsker å skrive ut kortene dine, eksporter dem til en tekstfil som du så kan skrive ut fra tekstbehandleren du bruker.</translation>
    </message>
    <message>
        <source>You can share your cards with someone else by exporting them to XML and choosing the &apos;Reset learning data&apos; option on export.</source>
        <translation>Du kan dele kortene dine med andre ved å eksportere dem til XML og velge &apos;Nullstill læringsdata&apos; ved eksport.</translation>
    </message>
    <message>
        <source>If you study a foreign language with a different script, the default font size is sometimes a bit small. If you want to increase the size of these characters but keep the size of English text, use the &apos;increase size of non-latin characters by X points&apos; option.</source>
        <translation>Hvis du studerer ett fremmedspråk med en annen skrift, vil standard skriftstørrelse noen ganger være for liten. Hvis du vil øke størrelsen på disse tegnene men beholde størrelse på latinske tegn, bruk &apos;Øk størrelsen til ikke-latinske tegne med X punkter&apos;-innstillingen.</translation>
    </message>
    <message>
        <source>You can add images and sounds to your cards. Right-click on the question or answer field when editing a card to bring up a pop-up menu to do so.</source>
        <translation>Du kan legge til bilder og lyder til kortene dine. For å gjøre dette, høyreklikk på spørsmål- eller svarfeltet når du redigerer ett kort for å bringe frem en hurtigmeny.</translation>
    </message>
    <message>
        <source>It is recommended to keep your sound and image files inside your .mnemosyne directory. That way, it&apos;s easier to transfer your data between different computers.</source>
        <translation>Det anbefales at du har lyd- og bildefilene i din .mnemosyne-mappe. På den måten er det enklere å overføre data mellom forskjelige datamaskiner.</translation>
    </message>
    <message>
        <source>When adding a three-sided card, two regular cards will be created. One with as question the written form and as answer the pronunciation and the translation, and one with as question the translation and as answer the written form and the pronunciation.</source>
        <translation>Når du legger til et 3-sidet kort, vil det bli opprettet 2 vanlige kort. Ett med spørsmål om den skriftlige formen og med uttalen og oversettelsen som svar, og  ett med oversettelsen som spørsmål og den skriftlige formen og uttalen som svar.</translation>
    </message>
    <message>
        <source>You can use basic HTML tags in your cards to control their appearance.</source>
        <translation>Du kan benytte grunnleggende HTML-koder i kortene dine for å kontrollere utformingen.</translation>
    </message>
    <message>
        <source>Mnemosyne can use LaTeX to render mathematical formulas, e.g. &lt;$&gt;x^2+y^2=z^2&lt;/$&gt;. (For this, you need LaTeX and dvipng installed.)</source>
        <translation>Mnemosyne kan bruke LaTeX for å gjengi  matematiske formler, f.eks. &lt;$&gt;x^2+y^2=z^2&lt;/$&gt;. (For å gjøre dette, må du ha LaTeX og dvipng installert.)</translation>
    </message>
    <message>
        <source>The best way to backup your data is to copy your .mnemosyne directory (if you follow the recommended procedure to keep all your files there) and move it to a different drive. Mnemosyne keeps automatic XML-based backups in .mnemosyne/backups, but that won&apos;t help you if that drive dies... </source>
        <translation>Den beste måten å sikkerhetskopiere dataene dine på er å kopiere .mnemosyne-mappa (hvis du følger anbefalingen om å ha alle filene dine der) og flytte den til en annen lagringsenhet. Mnemosyn holder automatisk XML-baserte sikkerhetshopier i .mnemosyne/backups, men det vil ikke hjelpe deg noe hvis denne lagringsenheten dør...</translation>
    </message>
    <message>
        <source>You can run Mnemosyne from a USB key. Copy C:\Program Files\Mnemosyne to your USB key, and then copy the .mnemosyne directory from your home directory to inside the Mnemosyne directory on the USB key.</source>
        <translation>Du kan kjøre Mnemosyne fra en USB minnepinne. Kopier C:\Programfiler\Mnemosyne til din minnepinne, og kopier .mnemosyne-mappen fra hjemmeområdet ditt til Mnemosyne-mappen på minnepinnen.</translation>
    </message>
    <message>
        <source>If you use Mnemosyne on multiple computers, there is a handy tool called Unison to help you synchronise your data. See the Mnemosyne website for more information.</source>
        <translation>Hvis du bruker Mnemosyne på flere forskjellige datamskiner, finnes det et nyttig verktøy kalt Unison som kan hjelpe deg å synkronisere dataene dine. Se hjemmesiden til Mnemosyne for mer informasjon.</translation>
    </message>
    <message>
        <source>You can sort the cards in the &apos;Edit Deck&apos; dialog by answer or by category by clicking on the corresponding column title. Clicking again changes the sort order.</source>
        <translation>Du kan sortere kortene i &apos;Rediger korstokk&apos;-dialogvinduet eller per kategori ved å klikke på de korresponderende kolonnetitlene. Ved å klikke igjen endres rekkefølgen.</translation>
    </message>
    <message>
        <source>If you want more fine-grained control over LaTeX&apos;s behaviour, see the explanation of the &lt;$$&gt;...&lt;/$$&gt; and &lt;latex&gt;...&lt;/latex&gt; tags on Mnemosyne&apos;s website.</source>
        <translation>Hvis du vil ha en mer finmasket kontroll over LaTeX&apos;s adferd, se forklaring på kodene &lt;$$&gt;...&lt;/$$&gt; og &lt;latex&gt;...&lt;/latex&gt; på Mnemosynes hjemmeside.</translation>
    </message>
    <message>
        <source>Advanced users can customise more of Mnemosyne by editing the config.py file in their .mnemosyne directory. They can also install plugins to customise Mnemosyne even further.</source>
        <translation>Avanserte brukere kan detaljstryre Mnemosyne ved å redigere config.py-filen i deres .mnemosyne-mappe. De kan også installere programtillegg for å skreddersy Mnemosyne ytterligere.</translation>
    </message>
</context>
<context>
    <name>TipFrm</name>
    <message>
        <source>Tip of the day</source>
        <translation>Dagens tips</translation>
    </message>
    <message>
        <source>&lt;b&gt;Did you know...?&lt;/b&gt;</source>
        <translation>&lt;b&gt;Visste du at...?&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&amp;Show tips on startup</source>
        <translation>&amp;Vis tips ved oppstart</translation>
    </message>
    <message>
        <source>Alt+S</source>
        <translation>Alt+S</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation>&amp;Forrige</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Neste</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
</TS>
